@@ -19,13 +19,6 @@ setMethod("show",
   signature = "SDMtune",
   definition = function(object) {
 
-    # TODO Remove this check in a feature release
-    if (.hasSlot(object@models[[1]], "p"))
-      stop("\nThis object was created using SDMtune v <= 0.1.1 and is now ",
-           "deprecated.\nCheck the article \"Deprecated objects\" in the ",
-           "package website to see how to convert this object into the new ",
-           "format.", call. = FALSE)
-
     tunable_hypers <- get_tunable_args(object@models[[1]])
 
     cat("Object of class: ", class(object), "\n\n")
